@@ -29,10 +29,11 @@ class Widget(widgets.DOMWidget, HasTraits):
     txt = Unicode('').tag(sync=True)
     colors = List([]).tag(sync=True)
     callback = Any()
-    dis = Bool(True).tag()
+    emojify = Bool(False).tag(sync=True)
+    dis = Bool(True).tag(sync=True)
     res = List([]).tag(sync=True)
 
-    def __init__(self, tags=[], txt='', colors=None, callback=None):
+    def __init__(self, tags=[], txt='', colors=None, callback=None, emojify=False):
         super(Widget, self).__init__()
 
         self.widget_id = Widget.__id
@@ -59,4 +60,6 @@ class Widget(widgets.DOMWidget, HasTraits):
         if len(tags) > len(self.colors): raise ValueError('colors should contain at least one unique color for each tag')
         self.tags = tags
 
-        self.observe(callback, names=['res'])
\ No newline at end of file
+        self.observe(callback, names=['res'])
+
+        self.emojify = emojify
\ No newline at end of file
